#
# spec file for package med
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%bcond_with need_clang

Name:           med
Version:        3.2.0
Release:        4.2
Summary:        Library to store and exchange meshed data or computation results
License:        GPL-3.0+
Group:          Productivity/Graphics/CAD
Url:            http://www.salome-platform.org/user-section/about/med
Source0:        med-3.2.0.tar.xz
BuildRequires:  hdf5-devel
#BuildRequires:  openmpi-devel
BuildRequires:  cmake
%if %{with need_clang}
BuildRequires:  llvm-clang
BuildRequires:  llvm
%else
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
%endif
BuildRequires:  xz
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The purpose of the MED module is to provide a standard for storing and recovering computer data associated to numerical meshes and fields, and to facilitate the exchange between codes and solvers. 

The persistent data storage is based upon HDF format (like CGNS, a standard developed by Boeing and NASA in the area of Computational Fluid Dynamic).

MED also provides structures to hold data on meshes and fields. These structures are exchanged between solvers, hide the communication level (CORBA or MPI), and offer persistence (read/write in .med files).


%package devel
Summary:        Development files for med
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Development files for med.


%prep
%setup -q -n %{name}-%{version}
sed -i -e "s:MEDequivInfo(int fid:MEDequivInfo(med_idt fid:g" src/2.3.6/ci/MEDequivInfo.c

%build
mkdir build
cd build
%if %{with need_clang}
    OPTFLAGS="$(echo %{optflags} | sed "s:-grecord-gcc-switches::g") -flto"
%else
    OPTFLAGS="%{optflags}"
%endif
  CFLAGS="$OPTFLAGS" \
  CXXFLAGS="$OPTFLAGS" \
  cmake \
   -DCMAKE_INSTALL_PREFIX=%{_prefix} \
   -DMEDFILE_BUILD_PYTHON=OFF \
   -DMEDFILE_BUILD_SHARED_LIBS=ON \
   -DMEDFILE_BUILD_STATIC_LIBS=OFF \
   -DMEDFILE_BUILD_TESTS=OFF \
   -DMEDFILE_INSTALL_DOC=OFF \
   -DMEDFILE_USE_MPI=OFF \
   ..
  make %{?_smp_mflags}
cd ..

%install
cd build
  make DESTDIR=%{buildroot} install %{?_smp_mflags}
cd ..
# fix install locations
%ifarch x86_64
mkdir -p %{buildroot}%{_libdir}
mv %{buildroot}%{_prefix}/lib/*.so %{buildroot}%{_libdir}
%endif
rm -rf %{buildroot}%{_prefix}/lib/*.a
mkdir -p %{buildroot}/%{_includedir}/med
mv %{buildroot}%{_includedir}/{*.h*,2.3.6} %{buildroot}%{_includedir}/med/
sed -i -e "s:SET(MEDFILE_INCLUDE_DIRS.*:SET(MEDFILE_INCLUDE_DIRS %{_includedir}/med):g" %{buildroot}%{_datadir}/cmake/MEDFile/MEDFileConfig.cmake

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/*
%{_libdir}/*.so

%files devel
%defattr(-,root,root)
%{_includedir}/med
%{_datadir}/cmake/MEDFile

%changelog
* Fri Sep 23 2016 johannesobermayr@gmx.de
- Initial package
